@@ -39,6 +39,9 @@ typedef struct _swSSL_option
     char *key_file;
     char *passphrase;
     char *client_cert_file;
+#ifdef SSL_CTRL_SET_TLSEXT_HOSTNAME
+    char *tls_host_name;
+#endif
     uint8_t verify_depth;
     uint8_t method;
     uint8_t disable_compress :1;
@@ -132,11 +135,11 @@ static sw_inline ssize_t swConnection_recv(swConnection *conn, void *__buf, size
     if (conn->ssl)
     {
         int ret = 0;
-        int written = 0;
+        int n_received = 0;
 
-        while(written < __n)
+        while (n_received < __n)
         {
-            ret = swSSL_recv(conn, ((char*)__buf) + written, __n - written);
+            ret = swSSL_recv(conn, ((char*)__buf) + n_received, __n - n_received);
             if (__flags & MSG_WAITALL)
             {
                 if (ret <= 0)
@@ -145,7 +148,7 @@ static sw_inline ssize_t swConnection_recv(swConnection *conn, void *__buf, size
                 }
                 else
                 {
-                    written += ret;
+                    n_received += ret;
                 }
             }
             else
@@ -154,7 +157,7 @@ static sw_inline ssize_t swConnection_recv(swConnection *conn, void *__buf, size
             }
         }
 
-        return written;
+        return n_received;
     }
     else
     {
