@@ -495,6 +495,13 @@ static void client_check_ssl_setting(swClient *cli, zval *zset TSRMLS_DC)
         convert_to_string(v);
         cli->ssl_option.passphrase = sw_strdup(Z_STRVAL_P(v));
     }
+#ifdef SSL_CTRL_SET_TLSEXT_HOSTNAME
+    if (php_swoole_array_get_value(vht, "tls_host_name", v))
+    {
+        convert_to_string(v);
+        cli->ssl_option.tls_host_name = sw_strdup(Z_STRVAL_P(v));
+    }
+#endif
     if (cli->ssl_option.cert_file && !cli->ssl_option.key_file)
     {
         swoole_php_fatal_error(E_ERROR, "ssl require key file.");
@@ -993,11 +1000,6 @@ swClient* php_swoole_client_new(zval *object, char *host, int host_len, int port
                 cli->close(cli);
                 goto create_socket;
             }
-            //clear history data
-            if (ret > 0)
-            {
-                swSocket_clean(cli->socket->fd);
-            }
             cli->reuse_count ++;
             zend_update_property_long(swoole_client_class_entry_ptr, object, ZEND_STRL("reuseCount"), cli->reuse_count TSRMLS_CC);
         }
@@ -1550,6 +1552,11 @@ static PHP_METHOD(swoole_client, recv)
         {
             goto check_return;
         }
+        else if (ret != header_len)
+        {
+            ret = 0;
+            goto check_return;
+        }
 
         buf_len = protocol->get_package_length(protocol, cli->socket, cli->buffer->str, ret);
 
@@ -1576,6 +1583,10 @@ static PHP_METHOD(swoole_client, recv)
         if (ret > 0)
         {
             ret += header_len;
+            if (ret != buf_len)
+            {
+                ret = 0;
+            }
         }
     }
     else
